(window["webpackJsonp"] = window["webpackJsonp"] || []).push([["geoRun"],{

/***/ "./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/ts-loader/index.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/GeoRun.vue?vue&type=script&lang=ts":
/*!****************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/cache-loader/dist/cjs.js??ref--13-0!./node_modules/babel-loader/lib!./node_modules/ts-loader??ref--13-2!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/views/GeoRun.vue?vue&type=script&lang=ts ***!
  \****************************************************************************************************************************************************************************************************************************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var core_js_modules_es_array_filter_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! core-js/modules/es.array.filter.js */ \"./node_modules/core-js/modules/es.array.filter.js\");\n/* harmony import */ var core_js_modules_es_array_filter_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_filter_js__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var core_js_modules_es_array_for_each_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! core-js/modules/es.array.for-each.js */ \"./node_modules/core-js/modules/es.array.for-each.js\");\n/* harmony import */ var core_js_modules_es_array_for_each_js__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_for_each_js__WEBPACK_IMPORTED_MODULE_1__);\n/* harmony import */ var core_js_modules_es_array_map_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! core-js/modules/es.array.map.js */ \"./node_modules/core-js/modules/es.array.map.js\");\n/* harmony import */ var core_js_modules_es_array_map_js__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_map_js__WEBPACK_IMPORTED_MODULE_2__);\n/* harmony import */ var core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! core-js/modules/es.object.to-string.js */ \"./node_modules/core-js/modules/es.object.to-string.js\");\n/* harmony import */ var core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_3__);\n/* harmony import */ var core_js_modules_es_regexp_exec_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! core-js/modules/es.regexp.exec.js */ \"./node_modules/core-js/modules/es.regexp.exec.js\");\n/* harmony import */ var core_js_modules_es_regexp_exec_js__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_regexp_exec_js__WEBPACK_IMPORTED_MODULE_4__);\n/* harmony import */ var core_js_modules_es_set_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! core-js/modules/es.set.js */ \"./node_modules/core-js/modules/es.set.js\");\n/* harmony import */ var core_js_modules_es_set_js__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_set_js__WEBPACK_IMPORTED_MODULE_5__);\n/* harmony import */ var core_js_modules_es_string_iterator_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! core-js/modules/es.string.iterator.js */ \"./node_modules/core-js/modules/es.string.iterator.js\");\n/* harmony import */ var core_js_modules_es_string_iterator_js__WEBPACK_IMPORTED_MODULE_6___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_string_iterator_js__WEBPACK_IMPORTED_MODULE_6__);\n/* harmony import */ var core_js_modules_es_string_replace_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! core-js/modules/es.string.replace.js */ \"./node_modules/core-js/modules/es.string.replace.js\");\n/* harmony import */ var core_js_modules_es_string_replace_js__WEBPACK_IMPORTED_MODULE_7___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_string_replace_js__WEBPACK_IMPORTED_MODULE_7__);\n/* harmony import */ var core_js_modules_web_dom_collections_for_each_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! core-js/modules/web.dom-collections.for-each.js */ \"./node_modules/core-js/modules/web.dom-collections.for-each.js\");\n/* harmony import */ var core_js_modules_web_dom_collections_for_each_js__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_web_dom_collections_for_each_js__WEBPACK_IMPORTED_MODULE_8__);\n/* harmony import */ var core_js_modules_web_dom_collections_iterator_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! core-js/modules/web.dom-collections.iterator.js */ \"./node_modules/core-js/modules/web.dom-collections.iterator.js\");\n/* harmony import */ var core_js_modules_web_dom_collections_iterator_js__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_web_dom_collections_iterator_js__WEBPACK_IMPORTED_MODULE_9__);\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/slicedToArray */ \"./node_modules/@babel/runtime/helpers/esm/slicedToArray.js\");\n/* harmony import */ var _vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! @vue/runtime-core */ \"./node_modules/@vue/runtime-core/dist/runtime-core.esm-bundler.js\");\n/* harmony import */ var _components_ChoroplethMap_vue__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! @/components/ChoroplethMap.vue */ \"./src/components/ChoroplethMap.vue\");\n/* harmony import */ var _components_GeoSlider_vue__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! @/components/GeoSlider.vue */ \"./src/components/GeoSlider.vue\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! d3-geo */ \"./node_modules/d3-geo/src/index.js\");\n/* harmony import */ var _api_API__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! @/api/API */ \"./src/api/API.ts\");\n/* harmony import */ var vue_router__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! vue-router */ \"./node_modules/vue-router/dist/vue-router.esm-bundler.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n/* harmony default export */ __webpack_exports__[\"default\"] = (Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"defineComponent\"])({\n  name: \"GeoRun\",\n  components: {\n    ChoroplethMap: _components_ChoroplethMap_vue__WEBPACK_IMPORTED_MODULE_12__[\"default\"],\n    GeoSlider: _components_GeoSlider_vue__WEBPACK_IMPORTED_MODULE_13__[\"default\"]\n  },\n  setup: function setup(props, ctx) {\n    var route = Object(vue_router__WEBPACK_IMPORTED_MODULE_16__[\"useRoute\"])();\n    var router = Object(vue_router__WEBPACK_IMPORTED_MODULE_16__[\"useRouter\"])();\n    var params = route.params;\n\n    var checkURLParams = function checkURLParams() {\n      var params = route.params;\n      if (params.project) projectId.value = params.project;\n      if (params.runId) runId.value = params.runId;\n      if (params.dim) selectedDimension.value = params.dim;\n    };\n\n    var setURLParams = function setURLParams() {\n      var addToHistory = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;\n      var path = {\n        name: \"geoRun\",\n        params: {\n          projectId: projectId.value,\n          runId: runId.value,\n          dim: selectedDimension.value\n        }\n      };\n      if (addToHistory) router.push(path);else router.replace(path);\n    };\n\n    Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"watch\"])(function () {\n      return route.params;\n    }, function (newV, oldV) {\n      checkURLParams();\n    });\n    var mapData = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"ref\"])([]);\n    var shapes = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"ref\"])(null);\n    var projection = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"ref\"])(null);\n    var projectId = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"ref\"])(params.project || \"mask_wearing\");\n    var runId = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"ref\"])(params.runId || \"6\");\n    var fieldExtent = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"ref\"])(null);\n    var availableDimensions = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"ref\"])([]);\n    var selectedDimension = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"ref\"])(params.dim || \"currently_dead\");\n    var currentV = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"ref\"])(0);\n    var allTimeSlots = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"ref\"])([]);\n    var selectedTimeIndex = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"ref\"])(0);\n    var regions = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"ref\"])([]);\n    var regionTraces = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"ref\"])([]); // const sparklines = ref({} as { [key: string]: number[] });\n\n    var runMetas = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"ref\"])({});\n\n    var sliderChanged = function sliderChanged(e) {\n      selectedTimeIndex.value = e.target.valueAsNumber;\n    };\n\n    var cm_width = 500;\n    var cm_height = 500;\n    var visibleGeoObject = {};\n\n    var calculateProjecion = function calculateProjecion(geoObj) {\n      var geoProjection = Object(d3_geo__WEBPACK_IMPORTED_MODULE_14__[\"geoMercator\"])();\n      geoProjection.fitSize([cm_width, cm_height], geoObj);\n      return geoProjection;\n    };\n\n    var sliderRange = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"computed\"])(function () {\n      return allTimeSlots.value.length - 1;\n    });\n    var selectedTime = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"computed\"])(function () {\n      return allTimeSlots.value[selectedTimeIndex.value];\n    });\n    var currentMapValues = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"computed\"])(function () {\n      var selIndex = selectedTimeIndex.value;\n      var selDim = selectedDimension.value;\n      if (shapes.value == null || projection.value == null || regionTraces.value.length < 1) return null;\n      var res = {};\n      regions.value.forEach(function (regionID, i) {\n        res[regionID] = regionTraces.value[i][selIndex][selDim];\n      });\n      return res;\n    });\n    var sparklines = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"computed\"])(function () {\n      var res = {};\n      regions.value.forEach(function (regionID, i) {\n        res[regionID] = regionTraces.value[i].map(function (t) {\n          return +t[selectedDimension.value];\n        });\n      });\n      return res;\n    });\n    var runMeta = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"computed\"])(function () {\n      return runMetas.value[runId.value];\n    });\n\n    var updateRunData = function updateRunData() {\n      Promise.all(regions.value.map(function (region) {\n        return Object(_api_API__WEBPACK_IMPORTED_MODULE_15__[\"getRegionTrace\"])(projectId.value, runId.value, region);\n      })).then(function (rT) {\n        regionTraces.value = rT;\n        allTimeSlots.value = rT[0].map(function (t) {\n          return t.timestamp;\n        });\n      });\n    };\n\n    var projectChange = function projectChange() {\n      Promise.all([Object(_api_API__WEBPACK_IMPORTED_MODULE_15__[\"allRegions\"])(projectId.value), Object(_api_API__WEBPACK_IMPORTED_MODULE_15__[\"getGeoData\"])(projectId.value), Object(_api_API__WEBPACK_IMPORTED_MODULE_15__[\"projectRunParameters\"])(projectId.value), Object(_api_API__WEBPACK_IMPORTED_MODULE_15__[\"numericFields\"])(projectId.value), Object(_api_API__WEBPACK_IMPORTED_MODULE_15__[\"getFieldExtent\"])(projectId.value, [selectedDimension.value])]).then(function (_ref) {\n        var _ref2 = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_10__[\"default\"])(_ref, 5),\n            allRegions = _ref2[0],\n            geoData = _ref2[1],\n            runMeta2 = _ref2[2],\n            allFields = _ref2[3],\n            maxRange = _ref2[4];\n\n        fieldExtent.value = maxRange;\n        var rM = Object.assign({}, runMeta2);\n        regions.value = allRegions;\n        var regionsSet = new Set(allRegions);\n        visibleGeoObject = {\n          type: \"FeatureCollection\",\n          features: geoData.features.filter(function (f) {\n            return regionsSet.has(f.properties.SSID) || allRegions.length === 0;\n          })\n        };\n        projection.value = calculateProjecion(visibleGeoObject); //@ts-ignore\n\n        shapes.value = visibleGeoObject;\n        runMetas.value = rM;\n        availableDimensions.value = allFields;\n        updateRunData();\n      });\n    };\n\n    Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"onMounted\"])(function () {\n      projectChange();\n    });\n    Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"watch\"])(function () {\n      return selectedDimension.value;\n    }, function () {\n      setURLParams(true);\n    });\n    Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"watch\"])(function () {\n      return runId.value;\n    }, function () {\n      updateRunData();\n      setURLParams(true);\n    });\n    Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"watch\"])(function () {\n      return projectId.value;\n    }, function (newV) {\n      projectChange();\n      setURLParams(true);\n    });\n    return {\n      projectId: projectId,\n      mapData: mapData,\n      shapes: shapes,\n      projection: projection,\n      cm_width: cm_width,\n      cm_height: cm_height,\n      sliderRange: sliderRange,\n      selectedTimeIndex: selectedTimeIndex,\n      selectedTime: selectedTime,\n      sliderChanged: sliderChanged,\n      currentMapValues: currentMapValues,\n      sparklines: sparklines,\n      currentV: currentV,\n      runId: runId,\n      runMetas: runMetas,\n      selectedDimension: selectedDimension,\n      availableDimensions: availableDimensions,\n      fieldExtent: fieldExtent\n    };\n  }\n}));\n\n//# sourceURL=webpack:///./src/views/GeoRun.vue?./node_modules/cache-loader/dist/cjs.js??ref--13-0!./node_modules/babel-loader/lib!./node_modules/ts-loader??ref--13-2!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/vue-loader-v16/dist/templateLoader.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/GeoRun.vue?vue&type=template&id=9fd62998&scoped=true":
/*!***********************************************************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/cache-loader/dist/cjs.js??ref--12-0!./node_modules/babel-loader/lib!./node_modules/vue-loader-v16/dist/templateLoader.js??ref--6!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/views/GeoRun.vue?vue&type=template&id=9fd62998&scoped=true ***!
  \***********************************************************************************************************************************************************************************************************************************************************************************************************************/
/*! exports provided: render */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"render\", function() { return render; });\n/* harmony import */ var core_js_modules_es_object_keys_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! core-js/modules/es.object.keys.js */ \"./node_modules/core-js/modules/es.object.keys.js\");\n/* harmony import */ var core_js_modules_es_object_keys_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_object_keys_js__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_objectSpread2__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/objectSpread2 */ \"./node_modules/@babel/runtime/helpers/esm/objectSpread2.js\");\n/* harmony import */ var vue__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! vue */ \"./node_modules/vue/dist/vue.runtime.esm-bundler.js\");\n\n\n\n\nvar _withId = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"withScopeId\"])(\"data-v-9fd62998\");\n\nObject(vue__WEBPACK_IMPORTED_MODULE_2__[\"pushScopeId\"])(\"data-v-9fd62998\");\n\nvar _hoisted_1 = {\n  class: \"me\"\n};\nvar _hoisted_2 = {\n  class: \"optionBox\"\n};\n\nvar _hoisted_3 = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"createVNode\"])(\"label\", {\n  for: \"runIDSel\"\n}, \"Run: \", -1\n/* HOISTED */\n);\n\nvar _hoisted_4 = {\n  class: \"optionBox\"\n};\n\nvar _hoisted_5 = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"createVNode\"])(\"label\", {\n  for: \"dimSel\"\n}, \"Dim: \", -1\n/* HOISTED */\n);\n\nObject(vue__WEBPACK_IMPORTED_MODULE_2__[\"popScopeId\"])();\n\nvar render = /*#__PURE__*/_withId(function (_ctx, _cache, $props, $setup, $data, $options) {\n  var _component_geo_slider = Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"resolveComponent\"])(\"geo-slider\");\n\n  return Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"openBlock\"])(), Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"createBlock\"])(\"div\", _hoisted_1, [Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"createVNode\"])(\"div\", _hoisted_2, [_hoisted_3, Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"withDirectives\"])(Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"createVNode\"])(\"select\", {\n    \"onUpdate:modelValue\": _cache[1] || (_cache[1] = function ($event) {\n      return _ctx.runId = $event;\n    }),\n    id: \"runIDSel\"\n  }, [(Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"openBlock\"])(true), Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"createBlock\"])(vue__WEBPACK_IMPORTED_MODULE_2__[\"Fragment\"], null, Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"renderList\"])(Object.keys(_ctx.runMetas), function (rm) {\n    return Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"openBlock\"])(), Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"createBlock\"])(\"option\", {\n      value: rm\n    }, Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"toDisplayString\"])(JSON.stringify(Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_objectSpread2__WEBPACK_IMPORTED_MODULE_1__[\"default\"])({\n      ID: rm\n    }, _ctx.runMetas[rm]))), 9\n    /* TEXT, PROPS */\n    , [\"value\"]);\n  }), 256\n  /* UNKEYED_FRAGMENT */\n  ))], 512\n  /* NEED_PATCH */\n  ), [[vue__WEBPACK_IMPORTED_MODULE_2__[\"vModelSelect\"], _ctx.runId]])]), Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"createVNode\"])(\"div\", _hoisted_4, [_hoisted_5, Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"withDirectives\"])(Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"createVNode\"])(\"select\", {\n    \"onUpdate:modelValue\": _cache[2] || (_cache[2] = function ($event) {\n      return _ctx.selectedDimension = $event;\n    }),\n    id: \"dimSel\"\n  }, [(Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"openBlock\"])(true), Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"createBlock\"])(vue__WEBPACK_IMPORTED_MODULE_2__[\"Fragment\"], null, Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"renderList\"])(_ctx.availableDimensions, function (dim) {\n    return Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"openBlock\"])(), Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"createBlock\"])(\"option\", {\n      value: dim\n    }, Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"toDisplayString\"])(dim), 9\n    /* TEXT, PROPS */\n    , [\"value\"]);\n  }), 256\n  /* UNKEYED_FRAGMENT */\n  ))], 512\n  /* NEED_PATCH */\n  ), [[vue__WEBPACK_IMPORTED_MODULE_2__[\"vModelSelect\"], _ctx.selectedDimension]])]), Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"createVNode\"])(_component_geo_slider, {\n    projectId: _ctx.projectId,\n    runId: _ctx.runId,\n    selectedDimension: _ctx.selectedDimension\n  }, null, 8\n  /* PROPS */\n  , [\"projectId\", \"runId\", \"selectedDimension\"]), Object(vue__WEBPACK_IMPORTED_MODULE_2__[\"createCommentVNode\"])(\" <ChoroplethMap\\n      v-if=\\\"currentMapValues\\\"\\n      :shapes=\\\"shapes\\\"\\n      :values=\\\"currentMapValues\\\"\\n      :valueRange=\\\"fieldExtent\\\"\\n      :sparklines=\\\"sparklines\\\"\\n      :projection=\\\"projection\\\"\\n      :width=\\\"cm_width\\\"\\n      :height=\\\"cm_height\\\"\\n      :sparklineDotIndex=\\\"selectedTimeIndex - 1\\\"\\n    />\\n\\n    <div class=\\\"slidecontainer\\\" :style=\\\"{ 'max-width': cm_width + 'px' }\\\">\\n      <input\\n        type=\\\"range\\\"\\n        min=\\\"1\\\"\\n        :max=\\\"sliderRange\\\"\\n        :value=\\\"selectedTimeIndex\\\"\\n        class=\\\"slider\\\"\\n        id=\\\"myRange\\\"\\n        @input=\\\"sliderChanged\\\"\\n      />\\n    </div>\\n    <div>{{ selectedTime }}</div> \")]);\n});\n\n//# sourceURL=webpack:///./src/views/GeoRun.vue?./node_modules/cache-loader/dist/cjs.js??ref--12-0!./node_modules/babel-loader/lib!./node_modules/vue-loader-v16/dist/templateLoader.js??ref--6!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/GeoRun.vue?vue&type=style&index=0&id=9fd62998&scoped=true&lang=css":
/*!*******************************************************************************************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/css-loader/dist/cjs.js??ref--6-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--6-oneOf-1-2!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/views/GeoRun.vue?vue&type=style&index=0&id=9fd62998&scoped=true&lang=css ***!
  \*******************************************************************************************************************************************************************************************************************************************************************************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("// Imports\nvar ___CSS_LOADER_API_IMPORT___ = __webpack_require__(/*! ../../node_modules/css-loader/dist/runtime/api.js */ \"./node_modules/css-loader/dist/runtime/api.js\");\nexports = ___CSS_LOADER_API_IMPORT___(false);\n// Module\nexports.push([module.i, \"\\nlabel[data-v-9fd62998] {\\n  font-weight: bold;\\n}\\n.optionBox[data-v-9fd62998] {\\n  margin: 10px 0;\\n  width: 100%;\\n  white-space: nowrap;\\n}\\nselect[data-v-9fd62998] {\\n  padding: 5px;\\n  border: none;\\n  font: inherit;\\n}\\n.me[data-v-9fd62998] {\\n  max-width: 700px;\\n  margin: 0 auto;\\n}\\n\\n/*.slidecontainer {*/\\n/*  width: 100%; !* Width of the outside container *!*/\\n/*  max-width: 700px;*/\\n/*}*/\\n\\n/* The slider itself */\\n.slider[data-v-9fd62998] {\\n  -webkit-appearance: none; /* Override default CSS styles */\\n  -moz-appearance: none;\\n       appearance: none;\\n  width: 100%; /* Full-width */\\n  height: 27px; /* Specified height */\\n  background: #d3d3d3; /* Grey background */\\n  outline: none; /* Remove outline */\\n  opacity: 0.7; /* Set transparency (for mouse-over effects on hover) */ /* 0.2 seconds transition on hover */\\n  transition: opacity 0.2s;\\n}\\n\\n/* Mouse-over effects */\\n.slider[data-v-9fd62998]:hover {\\n  opacity: 1; /* Fully shown on mouse-over */\\n}\\n\\n/* The slider handle (use -webkit- (Chrome, Opera, Safari, Edge) and -moz- (Firefox) to override default look) */\\n.slider[data-v-9fd62998]::-webkit-slider-thumb {\\n  -webkit-appearance: none; /* Override default look */\\n  appearance: none;\\n  width: 25px; /* Set a specific slider handle width */\\n  height: 25px; /* Slider handle height */\\n  border-radius: 7px;\\n  background: #333; /* Green background */\\n  cursor: pointer; /* Cursor on hover */\\n}\\n.slider[data-v-9fd62998]::-moz-range-thumb {\\n  width: 25px; /* Set a specific slider handle width */\\n  height: 25px; /* Slider handle height */\\n  border-radius: 5px;\\n  background: #333; /* Green background */\\n  cursor: pointer; /* Cursor on hover */\\n}\\n\", \"\"]);\n// Exports\nmodule.exports = exports;\n\n\n//# sourceURL=webpack:///./src/views/GeoRun.vue?./node_modules/css-loader/dist/cjs.js??ref--6-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--6-oneOf-1-2!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./node_modules/vue-style-loader/index.js?!./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/GeoRun.vue?vue&type=style&index=0&id=9fd62998&scoped=true&lang=css":
/*!*********************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/vue-style-loader??ref--6-oneOf-1-0!./node_modules/css-loader/dist/cjs.js??ref--6-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--6-oneOf-1-2!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/views/GeoRun.vue?vue&type=style&index=0&id=9fd62998&scoped=true&lang=css ***!
  \*********************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("// style-loader: Adds some css to the DOM by adding a <style> tag\n\n// load the styles\nvar content = __webpack_require__(/*! !../../node_modules/css-loader/dist/cjs.js??ref--6-oneOf-1-1!../../node_modules/vue-loader-v16/dist/stylePostLoader.js!../../node_modules/postcss-loader/src??ref--6-oneOf-1-2!../../node_modules/cache-loader/dist/cjs.js??ref--0-0!../../node_modules/vue-loader-v16/dist??ref--0-1!./GeoRun.vue?vue&type=style&index=0&id=9fd62998&scoped=true&lang=css */ \"./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/GeoRun.vue?vue&type=style&index=0&id=9fd62998&scoped=true&lang=css\");\nif(typeof content === 'string') content = [[module.i, content, '']];\nif(content.locals) module.exports = content.locals;\n// add the styles to the DOM\nvar add = __webpack_require__(/*! ../../node_modules/vue-style-loader/lib/addStylesClient.js */ \"./node_modules/vue-style-loader/lib/addStylesClient.js\").default\nvar update = add(\"be348d1c\", content, false, {\"sourceMap\":false,\"shadowMode\":false});\n// Hot Module Replacement\nif(false) {}\n\n//# sourceURL=webpack:///./src/views/GeoRun.vue?./node_modules/vue-style-loader??ref--6-oneOf-1-0!./node_modules/css-loader/dist/cjs.js??ref--6-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--6-oneOf-1-2!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./src/views/GeoRun.vue":
/*!******************************!*\
  !*** ./src/views/GeoRun.vue ***!
  \******************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _GeoRun_vue_vue_type_template_id_9fd62998_scoped_true__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./GeoRun.vue?vue&type=template&id=9fd62998&scoped=true */ \"./src/views/GeoRun.vue?vue&type=template&id=9fd62998&scoped=true\");\n/* harmony import */ var _GeoRun_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./GeoRun.vue?vue&type=script&lang=ts */ \"./src/views/GeoRun.vue?vue&type=script&lang=ts\");\n/* empty/unused harmony star reexport *//* harmony import */ var _GeoRun_vue_vue_type_style_index_0_id_9fd62998_scoped_true_lang_css__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./GeoRun.vue?vue&type=style&index=0&id=9fd62998&scoped=true&lang=css */ \"./src/views/GeoRun.vue?vue&type=style&index=0&id=9fd62998&scoped=true&lang=css\");\n\n\n\n\n\n_GeoRun_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"].render = _GeoRun_vue_vue_type_template_id_9fd62998_scoped_true__WEBPACK_IMPORTED_MODULE_0__[\"render\"]\n_GeoRun_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"].__scopeId = \"data-v-9fd62998\"\n/* hot reload */\nif (false) {}\n\n_GeoRun_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"].__file = \"src/views/GeoRun.vue\"\n\n/* harmony default export */ __webpack_exports__[\"default\"] = (_GeoRun_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"]);\n\n//# sourceURL=webpack:///./src/views/GeoRun.vue?");

/***/ }),

/***/ "./src/views/GeoRun.vue?vue&type=script&lang=ts":
/*!******************************************************!*\
  !*** ./src/views/GeoRun.vue?vue&type=script&lang=ts ***!
  \******************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _node_modules_cache_loader_dist_cjs_js_ref_13_0_node_modules_babel_loader_lib_index_js_node_modules_ts_loader_index_js_ref_13_2_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_GeoRun_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! -!../../node_modules/cache-loader/dist/cjs.js??ref--13-0!../../node_modules/babel-loader/lib!../../node_modules/ts-loader??ref--13-2!../../node_modules/cache-loader/dist/cjs.js??ref--0-0!../../node_modules/vue-loader-v16/dist??ref--0-1!./GeoRun.vue?vue&type=script&lang=ts */ \"./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/ts-loader/index.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/GeoRun.vue?vue&type=script&lang=ts\");\n/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, \"default\", function() { return _node_modules_cache_loader_dist_cjs_js_ref_13_0_node_modules_babel_loader_lib_index_js_node_modules_ts_loader_index_js_ref_13_2_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_GeoRun_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_0__[\"default\"]; });\n\n/* empty/unused harmony star reexport */ \n\n//# sourceURL=webpack:///./src/views/GeoRun.vue?");

/***/ }),

/***/ "./src/views/GeoRun.vue?vue&type=style&index=0&id=9fd62998&scoped=true&lang=css":
/*!**************************************************************************************!*\
  !*** ./src/views/GeoRun.vue?vue&type=style&index=0&id=9fd62998&scoped=true&lang=css ***!
  \**************************************************************************************/
/*! no static exports found */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _node_modules_vue_style_loader_index_js_ref_6_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_6_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_6_oneOf_1_2_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_GeoRun_vue_vue_type_style_index_0_id_9fd62998_scoped_true_lang_css__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! -!../../node_modules/vue-style-loader??ref--6-oneOf-1-0!../../node_modules/css-loader/dist/cjs.js??ref--6-oneOf-1-1!../../node_modules/vue-loader-v16/dist/stylePostLoader.js!../../node_modules/postcss-loader/src??ref--6-oneOf-1-2!../../node_modules/cache-loader/dist/cjs.js??ref--0-0!../../node_modules/vue-loader-v16/dist??ref--0-1!./GeoRun.vue?vue&type=style&index=0&id=9fd62998&scoped=true&lang=css */ \"./node_modules/vue-style-loader/index.js?!./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/GeoRun.vue?vue&type=style&index=0&id=9fd62998&scoped=true&lang=css\");\n/* harmony import */ var _node_modules_vue_style_loader_index_js_ref_6_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_6_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_6_oneOf_1_2_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_GeoRun_vue_vue_type_style_index_0_id_9fd62998_scoped_true_lang_css__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_node_modules_vue_style_loader_index_js_ref_6_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_6_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_6_oneOf_1_2_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_GeoRun_vue_vue_type_style_index_0_id_9fd62998_scoped_true_lang_css__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony reexport (unknown) */ for(var __WEBPACK_IMPORT_KEY__ in _node_modules_vue_style_loader_index_js_ref_6_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_6_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_6_oneOf_1_2_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_GeoRun_vue_vue_type_style_index_0_id_9fd62998_scoped_true_lang_css__WEBPACK_IMPORTED_MODULE_0__) if([\"default\"].indexOf(__WEBPACK_IMPORT_KEY__) < 0) (function(key) { __webpack_require__.d(__webpack_exports__, key, function() { return _node_modules_vue_style_loader_index_js_ref_6_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_6_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_6_oneOf_1_2_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_GeoRun_vue_vue_type_style_index_0_id_9fd62998_scoped_true_lang_css__WEBPACK_IMPORTED_MODULE_0__[key]; }) }(__WEBPACK_IMPORT_KEY__));\n\n\n//# sourceURL=webpack:///./src/views/GeoRun.vue?");

/***/ }),

/***/ "./src/views/GeoRun.vue?vue&type=template&id=9fd62998&scoped=true":
/*!************************************************************************!*\
  !*** ./src/views/GeoRun.vue?vue&type=template&id=9fd62998&scoped=true ***!
  \************************************************************************/
/*! exports provided: render */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _node_modules_cache_loader_dist_cjs_js_ref_12_0_node_modules_babel_loader_lib_index_js_node_modules_vue_loader_v16_dist_templateLoader_js_ref_6_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_GeoRun_vue_vue_type_template_id_9fd62998_scoped_true__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! -!../../node_modules/cache-loader/dist/cjs.js??ref--12-0!../../node_modules/babel-loader/lib!../../node_modules/vue-loader-v16/dist/templateLoader.js??ref--6!../../node_modules/cache-loader/dist/cjs.js??ref--0-0!../../node_modules/vue-loader-v16/dist??ref--0-1!./GeoRun.vue?vue&type=template&id=9fd62998&scoped=true */ \"./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/vue-loader-v16/dist/templateLoader.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/GeoRun.vue?vue&type=template&id=9fd62998&scoped=true\");\n/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, \"render\", function() { return _node_modules_cache_loader_dist_cjs_js_ref_12_0_node_modules_babel_loader_lib_index_js_node_modules_vue_loader_v16_dist_templateLoader_js_ref_6_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_GeoRun_vue_vue_type_template_id_9fd62998_scoped_true__WEBPACK_IMPORTED_MODULE_0__[\"render\"]; });\n\n\n\n//# sourceURL=webpack:///./src/views/GeoRun.vue?");

/***/ })

}]);