# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"init_available_projects": "00_Create Project.ipynb",
         "summarize_h5": "00_Create Project.ipynb",
         "pgrid_to_run_parameters": "00_Create Project.ipynb",
         "collect_statistics": "00_Create Project.ipynb",
         "fix_geojson": "00_Create Project.ipynb",
         "main": "00_Create Project.ipynb"}

modules = ["create_project.py"]

doc_url = "https://bhoov.github.io/JUNE-vis/"

git_url = "https://github.com/bhoov/JUNE-vis/tree/master/"

def custom_doc_links(name): return None
